Helper function to define a ridge penalty regularization object.
See define_penalty for more details.
define_ridge(
num_penalty = 20,
penalty_ratio = NULL,
user_penalty = NULL,
custom_multiplier = NULL
)A list object with regularization settings that are used to define
the regularization for predictors or external data in xrnet and
tune_xrnet. The list elements will match those returned by
define_penalty, but with the penalty_type automatically set
to 0.
number of penalty values to fit in grid. Default is 20.
ratio between minimum and maximum penalty for x. Default is 1e-04 if \(n > p\) and 0.01 if \(n <= p\).
user-defined vector of penalty values to use in penalty path.
variable-specific penalty multipliers to apply to overall penalty. Default is 1 for all variables. 0 is no penalization.