Control function for xrnet fitting.
xrnet_control(
tolerance = 1e-08,
max_iterations = 1e+05,
dfmax = NULL,
pmax = NULL,
lower_limits = NULL,
upper_limits = NULL
)A list object with the following components:
The coordinate descent stopping criterion.
The maximum number of variables that will be allowed in the model.
The maximum number of variables with nonzero coefficient estimate.
Feature-specific numeric vector of lower bounds for coefficient estimates
Feature-specific numeric vector of upper bounds for coefficient estimates
positive convergence criterion. Default is 1e-08.
maximum number of iterations to run coordinate gradient descent across all penalties before returning an error. Default is 1e+05.
maximum number of variables allowed in model. Default is \(ncol(x) + ncol(unpen) + ncol(external) + intercept[1] + intercept[2]\).
maximum number of variables with nonzero coefficient estimate. Default is \(min(2 * dfmax + 20, ncol(x) + ncol(unpen) + ncol(external) + intercept[2])\).
vector of lower limits for each coefficient. Default is -Inf for all variables.
vector of upper limits for each coefficient. Default is Inf for all variables.